Skip site navigation (1)Skip section navigation (2)

  
 
  

home | help
OGGZ-RIP(1)		     General Commands Manual		     OGGZ-RIP(1)

NAME
     oggz-rip - Extract one or more logical bitstreams from an Ogg file.

SYNOPSIS
     oggz-rip [-o filename | --output filename] filename

     oggz-rip [-h | --help] [-v | --version]

DESCRIPTION
     oggz-rip extracts one or more tracks from an Ogg file.  In Ogg terminology,
     oggz-rip extracts one or more logical bitstreams.

     For example, to extract just the Vorbis audio track from any Ogg file:

     oggz-rip -c vorbis input.ogx > output.ogg

     This  will remove any other tracks: Skeleton, Theora, image, etc.	The out-
     put will be a valid Ogg Vorbis I file, suitable for use on hardware players
     that do not support multiplexed (ie. multi-track) Ogg files.

     If the input file contains multiple bitstreams of the  desired  type,  then
     they can be selected by serialno with the -s option.  Use oggz-info to view
     the serialno of each track in a file.

OPTIONS
     oggz-rip accepts the following options:

   Miscellaneous options
     -o, --output filename
	    Write  output  to  the  specified filename instead of printing it to
	    standard output.

     -h, --help
	    Display usage information and exit.

     -v, --version
	    Output version information and exit.

   Filter options
     These options can be used multiple times. Pages matching ANY of the  filter
     options will be included into the output.

     -s, --serialno serialno
	    Output streams with given serialno.

     -i, --stream-index index
	    Filter  by	stream index. These are assigned to streams in the order
	    of their BOS pages, starting at 0.

     -c, --content-type content-type
	    Filter by content-type.  Run oggz-known-codecs(1) for a full list of
	    codecs known by the installed version of oggz.

EXAMPLES
     Extract all bitstreams from file.ogg:

	    oggz rip -o output.ogg file.ogg

     Extract only the Theora bitstream from file.ogv:

	    oggz rip -c theora -o output.ogv file.ogv

AUTHOR
     David Kuehling	   January  1, 2005;

COPYRIGHT
     Copyright (C) 2005 CSIRO Australia

SEE ALSO
     oggz-merge(1), oggz-chop(1), oggz-dump(1), oggz-diff(1), hogg(1)

				   May 3, 2013			     OGGZ-RIP(1)

Want to link to this manual page? Use this URL:
<https://man.freebsd.org/cgi/man.cgi?query=oggz-rip&sektion=1&manpath=FreeBSD+Ports+15.1.quarterly>

home | help